# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/conversion_or_adjustment_lag_bucket.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/conversion_or_adjustment_lag_bucket.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB$ConversionOrAdjustmentLagBucketProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nMgoogle/ads/googleads_v1/proto/enums/conversion_or_adjustment_lag_bucket.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xcb\x0c\n#ConversionOrAdjustmentLagBucketEnum\"\xa3\x0c\n\x1f\x43onversionOrAdjustmentLagBucket\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12 \n\x1c\x43ONVERSION_LESS_THAN_ONE_DAY\x10\x02\x12\x1e\n\x1a\x43ONVERSION_ONE_TO_TWO_DAYS\x10\x03\x12 \n\x1c\x43ONVERSION_TWO_TO_THREE_DAYS\x10\x04\x12!\n\x1d\x43ONVERSION_THREE_TO_FOUR_DAYS\x10\x05\x12 \n\x1c\x43ONVERSION_FOUR_TO_FIVE_DAYS\x10\x06\x12\x1f\n\x1b\x43ONVERSION_FIVE_TO_SIX_DAYS\x10\x07\x12 \n\x1c\x43ONVERSION_SIX_TO_SEVEN_DAYS\x10\x08\x12\"\n\x1e\x43ONVERSION_SEVEN_TO_EIGHT_DAYS\x10\t\x12!\n\x1d\x43ONVERSION_EIGHT_TO_NINE_DAYS\x10\n\x12\x1f\n\x1b\x43ONVERSION_NINE_TO_TEN_DAYS\x10\x0b\x12!\n\x1d\x43ONVERSION_TEN_TO_ELEVEN_DAYS\x10\x0c\x12$\n CONVERSION_ELEVEN_TO_TWELVE_DAYS\x10\r\x12&\n\"CONVERSION_TWELVE_TO_THIRTEEN_DAYS\x10\x0e\x12(\n$CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS\x10\x0f\x12*\n&CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS\x10\x10\x12(\n$CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS\x10\x11\x12(\n$CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS\x10\x12\x12\'\n#CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS\x10\x13\x12#\n\x1f\x43ONVERSION_SIXTY_TO_NINETY_DAYS\x10\x14\x12 \n\x1c\x41\x44JUSTMENT_LESS_THAN_ONE_DAY\x10\x15\x12\x1e\n\x1a\x41\x44JUSTMENT_ONE_TO_TWO_DAYS\x10\x16\x12 \n\x1c\x41\x44JUSTMENT_TWO_TO_THREE_DAYS\x10\x17\x12!\n\x1d\x41\x44JUSTMENT_THREE_TO_FOUR_DAYS\x10\x18\x12 \n\x1c\x41\x44JUSTMENT_FOUR_TO_FIVE_DAYS\x10\x19\x12\x1f\n\x1b\x41\x44JUSTMENT_FIVE_TO_SIX_DAYS\x10\x1a\x12 \n\x1c\x41\x44JUSTMENT_SIX_TO_SEVEN_DAYS\x10\x1b\x12\"\n\x1e\x41\x44JUSTMENT_SEVEN_TO_EIGHT_DAYS\x10\x1c\x12!\n\x1d\x41\x44JUSTMENT_EIGHT_TO_NINE_DAYS\x10\x1d\x12\x1f\n\x1b\x41\x44JUSTMENT_NINE_TO_TEN_DAYS\x10\x1e\x12!\n\x1d\x41\x44JUSTMENT_TEN_TO_ELEVEN_DAYS\x10\x1f\x12$\n ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS\x10 \x12&\n\"ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS\x10!\x12(\n$ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS\x10\"\x12*\n&ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS\x10#\x12(\n$ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS\x10$\x12(\n$ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS\x10%\x12\'\n#ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS\x10&\x12#\n\x1f\x41\x44JUSTMENT_SIXTY_TO_NINETY_DAYS\x10\'\x12\x38\n4ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS\x10(\x12\x16\n\x12\x43ONVERSION_UNKNOWN\x10)\x12\x16\n\x12\x41\x44JUSTMENT_UNKNOWN\x10*B\xf9\x01\n!com.google.ads.googleads.v1.enumsB$ConversionOrAdjustmentLagBucketProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET = _descriptor.EnumDescriptor(
  name='ConversionOrAdjustmentLagBucket',
  full_name='google.ads.googleads.v1.enums.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_LESS_THAN_ONE_DAY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_ONE_TO_TWO_DAYS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TWO_TO_THREE_DAYS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_THREE_TO_FOUR_DAYS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FOUR_TO_FIVE_DAYS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FIVE_TO_SIX_DAYS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_SIX_TO_SEVEN_DAYS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_SEVEN_TO_EIGHT_DAYS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_EIGHT_TO_NINE_DAYS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_NINE_TO_TEN_DAYS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TEN_TO_ELEVEN_DAYS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_ELEVEN_TO_TWELVE_DAYS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TWELVE_TO_THIRTEEN_DAYS', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_SIXTY_TO_NINETY_DAYS', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_LESS_THAN_ONE_DAY', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_ONE_TO_TWO_DAYS', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TWO_TO_THREE_DAYS', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_THREE_TO_FOUR_DAYS', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FOUR_TO_FIVE_DAYS', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FIVE_TO_SIX_DAYS', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_SIX_TO_SEVEN_DAYS', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_SEVEN_TO_EIGHT_DAYS', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_EIGHT_TO_NINE_DAYS', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_NINE_TO_TEN_DAYS', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TEN_TO_ELEVEN_DAYS', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS', index=38, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_SIXTY_TO_NINETY_DAYS', index=39, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS', index=40, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_UNKNOWN', index=41, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_UNKNOWN', index=42, number=42,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=183,
  serialized_end=1754,
)
_sym_db.RegisterEnumDescriptor(_CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET)


_CONVERSIONORADJUSTMENTLAGBUCKETENUM = _descriptor.Descriptor(
  name='ConversionOrAdjustmentLagBucketEnum',
  full_name='google.ads.googleads.v1.enums.ConversionOrAdjustmentLagBucketEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=1754,
)

_CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET.containing_type = _CONVERSIONORADJUSTMENTLAGBUCKETENUM
DESCRIPTOR.message_types_by_name['ConversionOrAdjustmentLagBucketEnum'] = _CONVERSIONORADJUSTMENTLAGBUCKETENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConversionOrAdjustmentLagBucketEnum = _reflection.GeneratedProtocolMessageType('ConversionOrAdjustmentLagBucketEnum', (_message.Message,), dict(
  DESCRIPTOR = _CONVERSIONORADJUSTMENTLAGBUCKETENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.conversion_or_adjustment_lag_bucket_pb2'
  ,
  __doc__ = """Container for enum representing the number of days between the
  impression and the conversion or between the impression and adjustments
  to the conversion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.ConversionOrAdjustmentLagBucketEnum)
  ))
_sym_db.RegisterMessage(ConversionOrAdjustmentLagBucketEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/ad_group_ad_asset_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import policy_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2
from google.ads.google_ads.v2.proto.enums import asset_field_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__field__type__pb2
from google.ads.google_ads.v2.proto.enums import asset_performance_label_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__performance__label__pb2
from google.ads.google_ads.v2.proto.enums import policy_approval_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2
from google.ads.google_ads.v2.proto.enums import policy_review_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/ad_group_ad_asset_view.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\027AdGroupAdAssetViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nDgoogle/ads/googleads_v2/proto/resources/ad_group_ad_asset_view.proto\x12!google.ads.googleads.v2.resources\x1a\x31google/ads/googleads_v2/proto/common/policy.proto\x1a:google/ads/googleads_v2/proto/enums/asset_field_type.proto\x1a\x41google/ads/googleads_v2/proto/enums/asset_performance_label.proto\x1a@google/ads/googleads_v2/proto/enums/policy_approval_status.proto\x1a>google/ads/googleads_v2/proto/enums/policy_review_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xa4\x03\n\x12\x41\x64GroupAdAssetView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x31\n\x0b\x61\x64_group_ad\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x61sset\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12T\n\nfield_type\x18\x02 \x01(\x0e\x32@.google.ads.googleads.v2.enums.AssetFieldTypeEnum.AssetFieldType\x12V\n\x0epolicy_summary\x18\x03 \x01(\x0b\x32>.google.ads.googleads.v2.resources.AdGroupAdAssetPolicySummary\x12i\n\x11performance_label\x18\x04 \x01(\x0e\x32N.google.ads.googleads.v2.enums.AssetPerformanceLabelEnum.AssetPerformanceLabel\"\xb5\x02\n\x1b\x41\x64GroupAdAssetPolicySummary\x12N\n\x14policy_topic_entries\x18\x01 \x03(\x0b\x32\x30.google.ads.googleads.v2.common.PolicyTopicEntry\x12_\n\rreview_status\x18\x02 \x01(\x0e\x32H.google.ads.googleads.v2.enums.PolicyReviewStatusEnum.PolicyReviewStatus\x12\x65\n\x0f\x61pproval_status\x18\x03 \x01(\x0e\x32L.google.ads.googleads.v2.enums.PolicyApprovalStatusEnum.PolicyApprovalStatusB\x84\x02\n%com.google.ads.googleads.v2.resourcesB\x17\x41\x64GroupAdAssetViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__field__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__performance__label__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ADGROUPADASSETVIEW = _descriptor.Descriptor(
  name='AdGroupAdAssetView',
  full_name='google.ads.googleads.v2.resources.AdGroupAdAssetView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetView.ad_group_ad', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetView.asset', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_type', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetView.field_type', index=3,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_summary', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetView.policy_summary', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performance_label', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetView.performance_label', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=898,
)


_ADGROUPADASSETPOLICYSUMMARY = _descriptor.Descriptor(
  name='AdGroupAdAssetPolicySummary',
  full_name='google.ads.googleads.v2.resources.AdGroupAdAssetPolicySummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_topic_entries', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetPolicySummary.policy_topic_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='review_status', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetPolicySummary.review_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approval_status', full_name='google.ads.googleads.v2.resources.AdGroupAdAssetPolicySummary.approval_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=901,
  serialized_end=1210,
)

_ADGROUPADASSETVIEW.fields_by_name['ad_group_ad'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPADASSETVIEW.fields_by_name['asset'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPADASSETVIEW.fields_by_name['field_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__field__type__pb2._ASSETFIELDTYPEENUM_ASSETFIELDTYPE
_ADGROUPADASSETVIEW.fields_by_name['policy_summary'].message_type = _ADGROUPADASSETPOLICYSUMMARY
_ADGROUPADASSETVIEW.fields_by_name['performance_label'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_asset__performance__label__pb2._ASSETPERFORMANCELABELENUM_ASSETPERFORMANCELABEL
_ADGROUPADASSETPOLICYSUMMARY.fields_by_name['policy_topic_entries'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2._POLICYTOPICENTRY
_ADGROUPADASSETPOLICYSUMMARY.fields_by_name['review_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2._POLICYREVIEWSTATUSENUM_POLICYREVIEWSTATUS
_ADGROUPADASSETPOLICYSUMMARY.fields_by_name['approval_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2._POLICYAPPROVALSTATUSENUM_POLICYAPPROVALSTATUS
DESCRIPTOR.message_types_by_name['AdGroupAdAssetView'] = _ADGROUPADASSETVIEW
DESCRIPTOR.message_types_by_name['AdGroupAdAssetPolicySummary'] = _ADGROUPADASSETPOLICYSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupAdAssetView = _reflection.GeneratedProtocolMessageType('AdGroupAdAssetView', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPADASSETVIEW,
  __module__ = 'google.ads.googleads_v2.proto.resources.ad_group_ad_asset_view_pb2'
  ,
  __doc__ = """A link between an AdGroupAd and an Asset.
  
  
  Attributes:
      resource_name:
          The resource name of the ad group ad asset view. Ad group ad
          asset view resource names have the form:  ``customers/{custome
          r_id}/adGroupAdAssets/{AdGroupAdAsset.ad_group_id}~{AdGroupAdA
          sset.ad.ad_id}~{AdGroupAdAsset.asset_id}~{AdGroupAdAsset.asset
          _field_type}``
      ad_group_ad:
          The ad group ad to which the asset is linked.
      asset:
          The asset which is linked to the ad group ad.
      field_type:
          Role that the asset takes in the ad.
      policy_summary:
          Policy information for the ad group ad asset.
      performance_label:
          Performance of an asset linkage.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AdGroupAdAssetView)
  ))
_sym_db.RegisterMessage(AdGroupAdAssetView)

AdGroupAdAssetPolicySummary = _reflection.GeneratedProtocolMessageType('AdGroupAdAssetPolicySummary', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPADASSETPOLICYSUMMARY,
  __module__ = 'google.ads.googleads_v2.proto.resources.ad_group_ad_asset_view_pb2'
  ,
  __doc__ = """Contains policy information for an ad group ad asset.
  
  
  Attributes:
      policy_topic_entries:
          The list of policy findings for the ad group ad asset.
      review_status:
          Where in the review process this ad group ad asset is.
      approval_status:
          The overall approval status of this ad group ad asset,
          calculated based on the status of its individual policy topic
          entries.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AdGroupAdAssetPolicySummary)
  ))
_sym_db.RegisterMessage(AdGroupAdAssetPolicySummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/geographic_view_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import geographic_view_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geographic__view__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/geographic_view_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\032GeographicViewServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nDgoogle/ads/googleads_v1/proto/services/geographic_view_service.proto\x12 google.ads.googleads.v1.services\x1a=google/ads/googleads_v1/proto/resources/geographic_view.proto\x1a\x1cgoogle/api/annotations.proto\"1\n\x18GetGeographicViewRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd7\x01\n\x15GeographicViewService\x12\xbd\x01\n\x11GetGeographicView\x12:.google.ads.googleads.v1.services.GetGeographicViewRequest\x1a\x31.google.ads.googleads.v1.resources.GeographicView\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/{resource_name=customers/*/geographicViews/*}B\x81\x02\n$com.google.ads.googleads.v1.servicesB\x1aGeographicViewServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geographic__view__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETGEOGRAPHICVIEWREQUEST = _descriptor.Descriptor(
  name='GetGeographicViewRequest',
  full_name='google.ads.googleads.v1.services.GetGeographicViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetGeographicViewRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=248,
)

DESCRIPTOR.message_types_by_name['GetGeographicViewRequest'] = _GETGEOGRAPHICVIEWREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetGeographicViewRequest = _reflection.GeneratedProtocolMessageType('GetGeographicViewRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETGEOGRAPHICVIEWREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.geographic_view_service_pb2'
  ,
  __doc__ = """Request message for
  [GeographicViewService.GetGeographicView][google.ads.googleads.v1.services.GeographicViewService.GetGeographicView].
  
  
  Attributes:
      resource_name:
          The resource name of the geographic view to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetGeographicViewRequest)
  ))
_sym_db.RegisterMessage(GetGeographicViewRequest)


DESCRIPTOR._options = None

_GEOGRAPHICVIEWSERVICE = _descriptor.ServiceDescriptor(
  name='GeographicViewService',
  full_name='google.ads.googleads.v1.services.GeographicViewService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=251,
  serialized_end=466,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetGeographicView',
    full_name='google.ads.googleads.v1.services.GeographicViewService.GetGeographicView',
    index=0,
    containing_service=None,
    input_type=_GETGEOGRAPHICVIEWREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geographic__view__pb2._GEOGRAPHICVIEW,
    serialized_options=_b('\202\323\344\223\0023\0221/v1/{resource_name=customers/*/geographicViews/*}'),
  ),
])
_sym_db.RegisterServiceDescriptor(_GEOGRAPHICVIEWSERVICE)

DESCRIPTOR.services_by_name['GeographicViewService'] = _GEOGRAPHICVIEWSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/bidding.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import page_one_promoted_strategy_goal_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_page__one__promoted__strategy__goal__pb2
from google.ads.google_ads.v1.proto.enums import target_impression_share_location_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_target__impression__share__location__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/bidding.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\014BiddingProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n2google/ads/googleads_v1/proto/common/bidding.proto\x12\x1egoogle.ads.googleads.v1.common\x1aIgoogle/ads/googleads_v1/proto/enums/page_one_promoted_strategy_goal.proto\x1aJgoogle/ads/googleads_v1/proto/enums/target_impression_share_location.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"I\n\nCommission\x12;\n\x16\x63ommission_rate_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\r\n\x0b\x45nhancedCpc\"E\n\tManualCpc\x12\x38\n\x14\x65nhanced_cpc_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x0b\n\tManualCpm\"\x0b\n\tManualCpv\"\x15\n\x13MaximizeConversions\"L\n\x17MaximizeConversionValue\x12\x31\n\x0btarget_roas\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xc6\x03\n\x0fPageOnePromoted\x12q\n\rstrategy_goal\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v1.enums.PageOnePromotedStrategyGoalEnum.PageOnePromotedStrategyGoal\x12;\n\x16\x63pc_bid_ceiling_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0c\x62id_modifier\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x37\n\x13only_raise_cpc_bids\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n%raise_cpc_bid_when_budget_constrained\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\'raise_cpc_bid_when_quality_score_is_low\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xbb\x01\n\tTargetCpa\x12\x36\n\x11target_cpa_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16\x63pc_bid_ceiling_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x63pc_bid_floor_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x0b\n\tTargetCpm\"\x85\x02\n\x15TargetImpressionShare\x12p\n\x08location\x18\x01 \x01(\x0e\x32^.google.ads.googleads.v1.enums.TargetImpressionShareLocationEnum.TargetImpressionShareLocation\x12=\n\x18location_fraction_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16\x63pc_bid_ceiling_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xd2\x02\n\x12TargetOutrankShare\x12@\n\x1btarget_outrank_share_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x37\n\x11\x63ompetitor_domain\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x16\x63pc_bid_ceiling_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x13only_raise_cpc_bids\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\'raise_cpc_bid_when_quality_score_is_low\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xb7\x01\n\nTargetRoas\x12\x31\n\x0btarget_roas\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x16\x63pc_bid_ceiling_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x63pc_bid_floor_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x84\x01\n\x0bTargetSpend\x12\x38\n\x13target_spend_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16\x63pc_bid_ceiling_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x83\x01\n\nPercentCpc\x12;\n\x16\x63pc_bid_ceiling_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x14\x65nhanced_cpc_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\xe7\x01\n\"com.google.ads.googleads.v1.commonB\x0c\x42iddingProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_page__one__promoted__strategy__goal__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_target__impression__share__location__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_COMMISSION = _descriptor.Descriptor(
  name='Commission',
  full_name='google.ads.googleads.v1.common.Commission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commission_rate_micros', full_name='google.ads.googleads.v1.common.Commission.commission_rate_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=372,
)


_ENHANCEDCPC = _descriptor.Descriptor(
  name='EnhancedCpc',
  full_name='google.ads.googleads.v1.common.EnhancedCpc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=387,
)


_MANUALCPC = _descriptor.Descriptor(
  name='ManualCpc',
  full_name='google.ads.googleads.v1.common.ManualCpc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enhanced_cpc_enabled', full_name='google.ads.googleads.v1.common.ManualCpc.enhanced_cpc_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=458,
)


_MANUALCPM = _descriptor.Descriptor(
  name='ManualCpm',
  full_name='google.ads.googleads.v1.common.ManualCpm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=471,
)


_MANUALCPV = _descriptor.Descriptor(
  name='ManualCpv',
  full_name='google.ads.googleads.v1.common.ManualCpv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=484,
)


_MAXIMIZECONVERSIONS = _descriptor.Descriptor(
  name='MaximizeConversions',
  full_name='google.ads.googleads.v1.common.MaximizeConversions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=507,
)


_MAXIMIZECONVERSIONVALUE = _descriptor.Descriptor(
  name='MaximizeConversionValue',
  full_name='google.ads.googleads.v1.common.MaximizeConversionValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_roas', full_name='google.ads.googleads.v1.common.MaximizeConversionValue.target_roas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=585,
)


_PAGEONEPROMOTED = _descriptor.Descriptor(
  name='PageOnePromoted',
  full_name='google.ads.googleads.v1.common.PageOnePromoted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_goal', full_name='google.ads.googleads.v1.common.PageOnePromoted.strategy_goal', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_ceiling_micros', full_name='google.ads.googleads.v1.common.PageOnePromoted.cpc_bid_ceiling_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier', full_name='google.ads.googleads.v1.common.PageOnePromoted.bid_modifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='only_raise_cpc_bids', full_name='google.ads.googleads.v1.common.PageOnePromoted.only_raise_cpc_bids', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raise_cpc_bid_when_budget_constrained', full_name='google.ads.googleads.v1.common.PageOnePromoted.raise_cpc_bid_when_budget_constrained', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raise_cpc_bid_when_quality_score_is_low', full_name='google.ads.googleads.v1.common.PageOnePromoted.raise_cpc_bid_when_quality_score_is_low', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=1042,
)


_TARGETCPA = _descriptor.Descriptor(
  name='TargetCpa',
  full_name='google.ads.googleads.v1.common.TargetCpa',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_cpa_micros', full_name='google.ads.googleads.v1.common.TargetCpa.target_cpa_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_ceiling_micros', full_name='google.ads.googleads.v1.common.TargetCpa.cpc_bid_ceiling_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_floor_micros', full_name='google.ads.googleads.v1.common.TargetCpa.cpc_bid_floor_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1232,
)


_TARGETCPM = _descriptor.Descriptor(
  name='TargetCpm',
  full_name='google.ads.googleads.v1.common.TargetCpm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1245,
)


_TARGETIMPRESSIONSHARE = _descriptor.Descriptor(
  name='TargetImpressionShare',
  full_name='google.ads.googleads.v1.common.TargetImpressionShare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='google.ads.googleads.v1.common.TargetImpressionShare.location', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_fraction_micros', full_name='google.ads.googleads.v1.common.TargetImpressionShare.location_fraction_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_ceiling_micros', full_name='google.ads.googleads.v1.common.TargetImpressionShare.cpc_bid_ceiling_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1509,
)


_TARGETOUTRANKSHARE = _descriptor.Descriptor(
  name='TargetOutrankShare',
  full_name='google.ads.googleads.v1.common.TargetOutrankShare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_outrank_share_micros', full_name='google.ads.googleads.v1.common.TargetOutrankShare.target_outrank_share_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='competitor_domain', full_name='google.ads.googleads.v1.common.TargetOutrankShare.competitor_domain', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_ceiling_micros', full_name='google.ads.googleads.v1.common.TargetOutrankShare.cpc_bid_ceiling_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='only_raise_cpc_bids', full_name='google.ads.googleads.v1.common.TargetOutrankShare.only_raise_cpc_bids', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raise_cpc_bid_when_quality_score_is_low', full_name='google.ads.googleads.v1.common.TargetOutrankShare.raise_cpc_bid_when_quality_score_is_low', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1850,
)


_TARGETROAS = _descriptor.Descriptor(
  name='TargetRoas',
  full_name='google.ads.googleads.v1.common.TargetRoas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_roas', full_name='google.ads.googleads.v1.common.TargetRoas.target_roas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_ceiling_micros', full_name='google.ads.googleads.v1.common.TargetRoas.cpc_bid_ceiling_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_floor_micros', full_name='google.ads.googleads.v1.common.TargetRoas.cpc_bid_floor_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1853,
  serialized_end=2036,
)


_TARGETSPEND = _descriptor.Descriptor(
  name='TargetSpend',
  full_name='google.ads.googleads.v1.common.TargetSpend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_spend_micros', full_name='google.ads.googleads.v1.common.TargetSpend.target_spend_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_ceiling_micros', full_name='google.ads.googleads.v1.common.TargetSpend.cpc_bid_ceiling_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2171,
)


_PERCENTCPC = _descriptor.Descriptor(
  name='PercentCpc',
  full_name='google.ads.googleads.v1.common.PercentCpc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpc_bid_ceiling_micros', full_name='google.ads.googleads.v1.common.PercentCpc.cpc_bid_ceiling_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhanced_cpc_enabled', full_name='google.ads.googleads.v1.common.PercentCpc.enhanced_cpc_enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2305,
)

_COMMISSION.fields_by_name['commission_rate_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MANUALCPC.fields_by_name['enhanced_cpc_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MAXIMIZECONVERSIONVALUE.fields_by_name['target_roas'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_PAGEONEPROMOTED.fields_by_name['strategy_goal'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_page__one__promoted__strategy__goal__pb2._PAGEONEPROMOTEDSTRATEGYGOALENUM_PAGEONEPROMOTEDSTRATEGYGOAL
_PAGEONEPROMOTED.fields_by_name['cpc_bid_ceiling_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_PAGEONEPROMOTED.fields_by_name['bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_PAGEONEPROMOTED.fields_by_name['only_raise_cpc_bids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PAGEONEPROMOTED.fields_by_name['raise_cpc_bid_when_budget_constrained'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PAGEONEPROMOTED.fields_by_name['raise_cpc_bid_when_quality_score_is_low'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TARGETCPA.fields_by_name['target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETCPA.fields_by_name['cpc_bid_ceiling_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETCPA.fields_by_name['cpc_bid_floor_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETIMPRESSIONSHARE.fields_by_name['location'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_target__impression__share__location__pb2._TARGETIMPRESSIONSHARELOCATIONENUM_TARGETIMPRESSIONSHARELOCATION
_TARGETIMPRESSIONSHARE.fields_by_name['location_fraction_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETIMPRESSIONSHARE.fields_by_name['cpc_bid_ceiling_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETOUTRANKSHARE.fields_by_name['target_outrank_share_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_TARGETOUTRANKSHARE.fields_by_name['competitor_domain'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TARGETOUTRANKSHARE.fields_by_name['cpc_bid_ceiling_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETOUTRANKSHARE.fields_by_name['only_raise_cpc_bids'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TARGETOUTRANKSHARE.fields_by_name['raise_cpc_bid_when_quality_score_is_low'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TARGETROAS.fields_by_name['target_roas'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TARGETROAS.fields_by_name['cpc_bid_ceiling_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETROAS.fields_by_name['cpc_bid_floor_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETSPEND.fields_by_name['target_spend_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TARGETSPEND.fields_by_name['cpc_bid_ceiling_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_PERCENTCPC.fields_by_name['cpc_bid_ceiling_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_PERCENTCPC.fields_by_name['enhanced_cpc_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['Commission'] = _COMMISSION
DESCRIPTOR.message_types_by_name['EnhancedCpc'] = _ENHANCEDCPC
DESCRIPTOR.message_types_by_name['ManualCpc'] = _MANUALCPC
DESCRIPTOR.message_types_by_name['ManualCpm'] = _MANUALCPM
DESCRIPTOR.message_types_by_name['ManualCpv'] = _MANUALCPV
DESCRIPTOR.message_types_by_name['MaximizeConversions'] = _MAXIMIZECONVERSIONS
DESCRIPTOR.message_types_by_name['MaximizeConversionValue'] = _MAXIMIZECONVERSIONVALUE
DESCRIPTOR.message_types_by_name['PageOnePromoted'] = _PAGEONEPROMOTED
DESCRIPTOR.message_types_by_name['TargetCpa'] = _TARGETCPA
DESCRIPTOR.message_types_by_name['TargetCpm'] = _TARGETCPM
DESCRIPTOR.message_types_by_name['TargetImpressionShare'] = _TARGETIMPRESSIONSHARE
DESCRIPTOR.message_types_by_name['TargetOutrankShare'] = _TARGETOUTRANKSHARE
DESCRIPTOR.message_types_by_name['TargetRoas'] = _TARGETROAS
DESCRIPTOR.message_types_by_name['TargetSpend'] = _TARGETSPEND
DESCRIPTOR.message_types_by_name['PercentCpc'] = _PERCENTCPC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Commission = _reflection.GeneratedProtocolMessageType('Commission', (_message.Message,), dict(
  DESCRIPTOR = _COMMISSION,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """Commission is an automatic bidding strategy in which the advertiser pays
  a certain portion of the conversion value.
  
  
  Attributes:
      commission_rate_micros:
          Commission rate defines the portion of the conversion value
          that the advertiser will be billed. A commission rate of x
          should be passed into this field as (x \* 1,000,000). For
          example, 106,000 represents a commission rate of 0.106
          (10.6%).
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Commission)
  ))
_sym_db.RegisterMessage(Commission)

EnhancedCpc = _reflection.GeneratedProtocolMessageType('EnhancedCpc', (_message.Message,), dict(
  DESCRIPTOR = _ENHANCEDCPC,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bidding strategy that raises bids for clicks that seem more
  likely to lead to a conversion and lowers them for clicks where they
  seem less likely.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.EnhancedCpc)
  ))
_sym_db.RegisterMessage(EnhancedCpc)

ManualCpc = _reflection.GeneratedProtocolMessageType('ManualCpc', (_message.Message,), dict(
  DESCRIPTOR = _MANUALCPC,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """Manual click-based bidding where user pays per click.
  
  
  Attributes:
      enhanced_cpc_enabled:
          Whether bids are to be enhanced based on conversion optimizer
          data.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ManualCpc)
  ))
_sym_db.RegisterMessage(ManualCpc)

ManualCpm = _reflection.GeneratedProtocolMessageType('ManualCpm', (_message.Message,), dict(
  DESCRIPTOR = _MANUALCPM,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """Manual impression-based bidding where user pays per thousand
  impressions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ManualCpm)
  ))
_sym_db.RegisterMessage(ManualCpm)

ManualCpv = _reflection.GeneratedProtocolMessageType('ManualCpv', (_message.Message,), dict(
  DESCRIPTOR = _MANUALCPV,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """View based bidding where user pays per video view.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ManualCpv)
  ))
_sym_db.RegisterMessage(ManualCpv)

MaximizeConversions = _reflection.GeneratedProtocolMessageType('MaximizeConversions', (_message.Message,), dict(
  DESCRIPTOR = _MAXIMIZECONVERSIONS,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bidding strategy that sets bids to help get the most
  conversions for your campaign while spending your budget.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.MaximizeConversions)
  ))
_sym_db.RegisterMessage(MaximizeConversions)

MaximizeConversionValue = _reflection.GeneratedProtocolMessageType('MaximizeConversionValue', (_message.Message,), dict(
  DESCRIPTOR = _MAXIMIZECONVERSIONVALUE,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bidding strategy which tries to maximize conversion value
  given a daily budget.
  
  
  Attributes:
      target_roas:
          The target return on ad spend (ROAS) option. If set, the bid
          strategy will maximize revenue while averaging the target
          return on ad spend. If the target ROAS is high, the bid
          strategy may not be able to spend the full budget. If the
          target ROAS is not set, the bid strategy will aim to achieve
          the highest possible ROAS for the budget.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.MaximizeConversionValue)
  ))
_sym_db.RegisterMessage(MaximizeConversionValue)

PageOnePromoted = _reflection.GeneratedProtocolMessageType('PageOnePromoted', (_message.Message,), dict(
  DESCRIPTOR = _PAGEONEPROMOTED,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bidding strategy which sets CPC bids to target impressions
  on page one, or page one promoted slots on google.com.
  
  
  Attributes:
      strategy_goal:
          The strategy goal of where impressions are desired to be shown
          on search result pages.
      cpc_bid_ceiling_micros:
          Maximum bid limit that can be set by the bid strategy. The
          limit applies to all keywords managed by the strategy.
      bid_modifier:
          Bid multiplier to be applied to the relevant bid estimate
          (depending on the ``strategy_goal``) in determining a
          keyword's new CPC bid.
      only_raise_cpc_bids:
          Whether the strategy should always follow bid estimate
          changes, or only increase. If false, always sets a keyword's
          new bid to the current bid estimate. If true, only updates a
          keyword's bid if the current bid estimate is greater than the
          current bid.
      raise_cpc_bid_when_budget_constrained:
          Whether the strategy is allowed to raise bids when the
          throttling rate of the budget it is serving out of rises above
          a threshold.
      raise_cpc_bid_when_quality_score_is_low:
          Whether the strategy is allowed to raise bids on keywords with
          lower-range quality scores.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PageOnePromoted)
  ))
_sym_db.RegisterMessage(PageOnePromoted)

TargetCpa = _reflection.GeneratedProtocolMessageType('TargetCpa', (_message.Message,), dict(
  DESCRIPTOR = _TARGETCPA,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bid strategy that sets bids to help get as many conversions
  as possible at the target cost-per-acquisition (CPA) you set.
  
  
  Attributes:
      target_cpa_micros:
          Average CPA target. This target should be greater than or
          equal to minimum billable unit based on the currency for the
          account.
      cpc_bid_ceiling_micros:
          Maximum bid limit that can be set by the bid strategy. The
          limit applies to all keywords managed by the strategy.
      cpc_bid_floor_micros:
          Minimum bid limit that can be set by the bid strategy. The
          limit applies to all keywords managed by the strategy.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetCpa)
  ))
_sym_db.RegisterMessage(TargetCpa)

TargetCpm = _reflection.GeneratedProtocolMessageType('TargetCpm', (_message.Message,), dict(
  DESCRIPTOR = _TARGETCPM,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """Target CPM (cost per thousand impressions) is an automated bidding
  strategy that sets bids to optimize performance given the target CPM you
  set.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetCpm)
  ))
_sym_db.RegisterMessage(TargetCpm)

TargetImpressionShare = _reflection.GeneratedProtocolMessageType('TargetImpressionShare', (_message.Message,), dict(
  DESCRIPTOR = _TARGETIMPRESSIONSHARE,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bidding strategy that sets bids so that a certain
  percentage of search ads are shown at the top of the first page (or
  other targeted location). Next Id = 4
  
  
  Attributes:
      location:
          The targeted location on the search results page.
      location_fraction_micros:
          The desired fraction of ads to be shown in the targeted
          location in micros. E.g. 1% equals 10,000.
      cpc_bid_ceiling_micros:
          The highest CPC bid the automated bidding system is permitted
          to specify. This is a required field entered by the advertiser
          that sets the ceiling and specified in local micros.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetImpressionShare)
  ))
_sym_db.RegisterMessage(TargetImpressionShare)

TargetOutrankShare = _reflection.GeneratedProtocolMessageType('TargetOutrankShare', (_message.Message,), dict(
  DESCRIPTOR = _TARGETOUTRANKSHARE,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bidding strategy that sets bids based on the target
  fraction of auctions where the advertiser should outrank a specific
  competitor.
  
  
  Attributes:
      target_outrank_share_micros:
          The target fraction of auctions where the advertiser should
          outrank the competitor. The advertiser outranks the competitor
          in an auction if either the advertiser appears above the
          competitor in the search results, or appears in the search
          results when the competitor does not. Value must be between 1
          and 1000000, inclusive.
      competitor_domain:
          Competitor's visible domain URL.
      cpc_bid_ceiling_micros:
          Maximum bid limit that can be set by the bid strategy. The
          limit applies to all keywords managed by the strategy.
      only_raise_cpc_bids:
          Whether the strategy should always follow bid estimate
          changes, or only increase. If false, always set a keyword's
          new bid to the current bid estimate. If true, only updates a
          keyword's bid if the current bid estimate is greater than the
          current bid.
      raise_cpc_bid_when_quality_score_is_low:
          Whether the strategy is allowed to raise bids on keywords with
          lower-range quality scores.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetOutrankShare)
  ))
_sym_db.RegisterMessage(TargetOutrankShare)

TargetRoas = _reflection.GeneratedProtocolMessageType('TargetRoas', (_message.Message,), dict(
  DESCRIPTOR = _TARGETROAS,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bidding strategy that helps you maximize revenue while
  averaging a specific target return on ad spend (ROAS).
  
  
  Attributes:
      target_roas:
          Required. The desired revenue (based on conversion data) per
          unit of spend. Value must be between 0.01 and 1000.0,
          inclusive.
      cpc_bid_ceiling_micros:
          Maximum bid limit that can be set by the bid strategy. The
          limit applies to all keywords managed by the strategy.
      cpc_bid_floor_micros:
          Minimum bid limit that can be set by the bid strategy. The
          limit applies to all keywords managed by the strategy.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetRoas)
  ))
_sym_db.RegisterMessage(TargetRoas)

TargetSpend = _reflection.GeneratedProtocolMessageType('TargetSpend', (_message.Message,), dict(
  DESCRIPTOR = _TARGETSPEND,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """An automated bid strategy that sets your bids to help get as many clicks
  as possible within your budget.
  
  
  Attributes:
      target_spend_micros:
          The spend target under which to maximize clicks. A TargetSpend
          bidder will attempt to spend the smaller of this value or the
          natural throttling spend amount. If not specified, the budget
          is used as the spend target.
      cpc_bid_ceiling_micros:
          Maximum bid limit that can be set by the bid strategy. The
          limit applies to all keywords managed by the strategy.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetSpend)
  ))
_sym_db.RegisterMessage(TargetSpend)

PercentCpc = _reflection.GeneratedProtocolMessageType('PercentCpc', (_message.Message,), dict(
  DESCRIPTOR = _PERCENTCPC,
  __module__ = 'google.ads.googleads_v1.proto.common.bidding_pb2'
  ,
  __doc__ = """A bidding strategy where bids are a fraction of the advertised price for
  some good or service.
  
  
  Attributes:
      cpc_bid_ceiling_micros:
          Maximum bid limit that can be set by the bid strategy. This is
          an optional field entered by the advertiser and specified in
          local micros. Note: A zero value is interpreted in the same
          way as having bid\_ceiling undefined.
      enhanced_cpc_enabled:
          Adjusts the bid for each auction upward or downward, depending
          on the likelihood of a conversion. Individual bids may exceed
          cpc\_bid\_ceiling\_micros, but the average bid amount for a
          campaign should not.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PercentCpc)
  ))
_sym_db.RegisterMessage(PercentCpc)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/geo_target_constant_suggestion_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/geo_target_constant_suggestion_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB%GeoTargetConstantSuggestionErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\nOgoogle/ads/googleads_v1/proto/errors/geo_target_constant_suggestion_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xd8\x01\n$GeoTargetConstantSuggestionErrorEnum\"\xaf\x01\n GeoTargetConstantSuggestionError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1c\n\x18LOCATION_NAME_SIZE_LIMIT\x10\x02\x12\x17\n\x13LOCATION_NAME_LIMIT\x10\x03\x12\x18\n\x14INVALID_COUNTRY_CODE\x10\x04\x12\x1c\n\x18REQUEST_PARAMETERS_UNSET\x10\x05\x42\x80\x02\n\"com.google.ads.googleads.v1.errorsB%GeoTargetConstantSuggestionErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_GEOTARGETCONSTANTSUGGESTIONERRORENUM_GEOTARGETCONSTANTSUGGESTIONERROR = _descriptor.EnumDescriptor(
  name='GeoTargetConstantSuggestionError',
  full_name='google.ads.googleads.v1.errors.GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_NAME_SIZE_LIMIT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_NAME_LIMIT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_COUNTRY_CODE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUEST_PARAMETERS_UNSET', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=187,
  serialized_end=362,
)
_sym_db.RegisterEnumDescriptor(_GEOTARGETCONSTANTSUGGESTIONERRORENUM_GEOTARGETCONSTANTSUGGESTIONERROR)


_GEOTARGETCONSTANTSUGGESTIONERRORENUM = _descriptor.Descriptor(
  name='GeoTargetConstantSuggestionErrorEnum',
  full_name='google.ads.googleads.v1.errors.GeoTargetConstantSuggestionErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GEOTARGETCONSTANTSUGGESTIONERRORENUM_GEOTARGETCONSTANTSUGGESTIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=362,
)

_GEOTARGETCONSTANTSUGGESTIONERRORENUM_GEOTARGETCONSTANTSUGGESTIONERROR.containing_type = _GEOTARGETCONSTANTSUGGESTIONERRORENUM
DESCRIPTOR.message_types_by_name['GeoTargetConstantSuggestionErrorEnum'] = _GEOTARGETCONSTANTSUGGESTIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GeoTargetConstantSuggestionErrorEnum = _reflection.GeneratedProtocolMessageType('GeoTargetConstantSuggestionErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _GEOTARGETCONSTANTSUGGESTIONERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.geo_target_constant_suggestion_error_pb2'
  ,
  __doc__ = """Container for enum describing possible geo target constant suggestion
  errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.GeoTargetConstantSuggestionErrorEnum)
  ))
_sym_db.RegisterMessage(GeoTargetConstantSuggestionErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/campaign_draft.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import campaign_draft_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__draft__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/campaign_draft.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\022CampaignDraftProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n<google/ads/googleads_v2/proto/resources/campaign_draft.proto\x12!google.ads.googleads.v2.resources\x1a?google/ads/googleads_v2/proto/enums/campaign_draft_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc2\x03\n\rCampaignDraft\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12-\n\x08\x64raft_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\rbase_campaign\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x64raft_campaign\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x06status\x18\x06 \x01(\x0e\x32J.google.ads.googleads.v2.enums.CampaignDraftStatusEnum.CampaignDraftStatus\x12:\n\x16has_experiment_running\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16long_running_operation\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xff\x01\n%com.google.ads.googleads.v2.resourcesB\x12\x43\x61mpaignDraftProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__draft__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNDRAFT = _descriptor.Descriptor(
  name='CampaignDraft',
  full_name='google.ads.googleads.v2.resources.CampaignDraft',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.CampaignDraft.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='draft_id', full_name='google.ads.googleads.v2.resources.CampaignDraft.draft_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_campaign', full_name='google.ads.googleads.v2.resources.CampaignDraft.base_campaign', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.CampaignDraft.name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='draft_campaign', full_name='google.ads.googleads.v2.resources.CampaignDraft.draft_campaign', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.CampaignDraft.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_experiment_running', full_name='google.ads.googleads.v2.resources.CampaignDraft.has_experiment_running', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_running_operation', full_name='google.ads.googleads.v2.resources.CampaignDraft.long_running_operation', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=677,
)

_CAMPAIGNDRAFT.fields_by_name['draft_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNDRAFT.fields_by_name['base_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNDRAFT.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNDRAFT.fields_by_name['draft_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNDRAFT.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__draft__status__pb2._CAMPAIGNDRAFTSTATUSENUM_CAMPAIGNDRAFTSTATUS
_CAMPAIGNDRAFT.fields_by_name['has_experiment_running'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGNDRAFT.fields_by_name['long_running_operation'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['CampaignDraft'] = _CAMPAIGNDRAFT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignDraft = _reflection.GeneratedProtocolMessageType('CampaignDraft', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNDRAFT,
  __module__ = 'google.ads.googleads_v2.proto.resources.campaign_draft_pb2'
  ,
  __doc__ = """A campaign draft.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign draft. Campaign draft
          resource names have the form:  ``customers/{customer_id}/campa
          ignDrafts/{base_campaign_id}~{draft_id}``
      draft_id:
          The ID of the draft.  This field is read-only.
      base_campaign:
          The base campaign to which the draft belongs.
      name:
          The name of the campaign draft.  This field is required and
          should not be empty when creating new campaign drafts.  It
          must not contain any null (code point 0x0), NL line feed (code
          point 0xA) or carriage return (code point 0xD) characters.
      draft_campaign:
          Resource name of the Campaign that results from overlaying the
          draft changes onto the base campaign.  This field is read-
          only.
      status:
          The status of the campaign draft. This field is read-only.
          When a new campaign draft is added, the status defaults to
          PROPOSED.
      has_experiment_running:
          Whether there is an experiment based on this draft currently
          serving.
      long_running_operation:
          The resource name of the long-running operation that can be
          used to poll for completion of draft promotion. This is only
          set if the draft promotion is in progress or finished.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.CampaignDraft)
  ))
_sym_db.RegisterMessage(CampaignDraft)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/invoice.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import dates_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2
from google.ads.google_ads.v2.proto.enums import invoice_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_invoice__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/invoice.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\014InvoiceProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n5google/ads/googleads_v2/proto/resources/invoice.proto\x12!google.ads.googleads.v2.resources\x1a\x30google/ads/googleads_v2/proto/common/dates.proto\x1a\x36google/ads/googleads_v2/proto/enums/invoice_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xcf\x0c\n\x07Invoice\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12(\n\x02id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12H\n\x04type\x18\x03 \x01(\x0e\x32:.google.ads.googleads.v2.enums.InvoiceTypeEnum.InvoiceType\x12\x33\n\rbilling_setup\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13payments_account_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13payments_profile_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nissue_date\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x64ue_date\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x12service_date_range\x18\t \x01(\x0b\x32).google.ads.googleads.v2.common.DateRange\x12\x33\n\rcurrency_code\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n invoice_level_adjustments_micros\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16subtotal_amount_micros\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11tax_amount_micros\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13total_amount_micros\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x11\x63orrected_invoice\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11replaced_invoices\x18\x10 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07pdf_url\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x61\n\x18\x61\x63\x63ount_budget_summaries\x18\x12 \x03(\x0b\x32?.google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary\x1a\xb5\x04\n\x14\x41\x63\x63ountBudgetSummary\x12.\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19\x63ustomer_descriptive_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x61\x63\x63ount_budget\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13\x61\x63\x63ount_budget_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15purchase_order_number\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x16subtotal_amount_micros\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11tax_amount_micros\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13total_amount_micros\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12O\n\x1c\x62illable_activity_date_range\x18\t \x01(\x0b\x32).google.ads.googleads.v2.common.DateRangeB\xf9\x01\n%com.google.ads.googleads.v2.resourcesB\x0cInvoiceProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_invoice__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_INVOICE_ACCOUNTBUDGETSUMMARY = _descriptor.Descriptor(
  name='AccountBudgetSummary',
  full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.customer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_descriptive_name', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.customer_descriptive_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_budget', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.account_budget', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_budget_name', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.account_budget_name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_order_number', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.purchase_order_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subtotal_amount_micros', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.subtotal_amount_micros', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tax_amount_micros', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.tax_amount_micros', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_amount_micros', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.total_amount_micros', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billable_activity_date_range', full_name='google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary.billable_activity_date_range', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1311,
  serialized_end=1876,
)

_INVOICE = _descriptor.Descriptor(
  name='Invoice',
  full_name='google.ads.googleads.v2.resources.Invoice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.Invoice.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.Invoice.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.Invoice.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_setup', full_name='google.ads.googleads.v2.resources.Invoice.billing_setup', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_account_id', full_name='google.ads.googleads.v2.resources.Invoice.payments_account_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_profile_id', full_name='google.ads.googleads.v2.resources.Invoice.payments_profile_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issue_date', full_name='google.ads.googleads.v2.resources.Invoice.issue_date', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='due_date', full_name='google.ads.googleads.v2.resources.Invoice.due_date', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_date_range', full_name='google.ads.googleads.v2.resources.Invoice.service_date_range', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v2.resources.Invoice.currency_code', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invoice_level_adjustments_micros', full_name='google.ads.googleads.v2.resources.Invoice.invoice_level_adjustments_micros', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subtotal_amount_micros', full_name='google.ads.googleads.v2.resources.Invoice.subtotal_amount_micros', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tax_amount_micros', full_name='google.ads.googleads.v2.resources.Invoice.tax_amount_micros', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_amount_micros', full_name='google.ads.googleads.v2.resources.Invoice.total_amount_micros', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='corrected_invoice', full_name='google.ads.googleads.v2.resources.Invoice.corrected_invoice', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replaced_invoices', full_name='google.ads.googleads.v2.resources.Invoice.replaced_invoices', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdf_url', full_name='google.ads.googleads.v2.resources.Invoice.pdf_url', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_budget_summaries', full_name='google.ads.googleads.v2.resources.Invoice.account_budget_summaries', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOICE_ACCOUNTBUDGETSUMMARY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=1876,
)

_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['customer'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['customer_descriptive_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['account_budget'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['account_budget_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['purchase_order_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['subtotal_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['tax_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['total_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_INVOICE_ACCOUNTBUDGETSUMMARY.fields_by_name['billable_activity_date_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2._DATERANGE
_INVOICE_ACCOUNTBUDGETSUMMARY.containing_type = _INVOICE
_INVOICE.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_invoice__type__pb2._INVOICETYPEENUM_INVOICETYPE
_INVOICE.fields_by_name['billing_setup'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['payments_account_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['payments_profile_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['issue_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['due_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['service_date_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2._DATERANGE
_INVOICE.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['invoice_level_adjustments_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_INVOICE.fields_by_name['subtotal_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_INVOICE.fields_by_name['tax_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_INVOICE.fields_by_name['total_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_INVOICE.fields_by_name['corrected_invoice'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['replaced_invoices'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['pdf_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_INVOICE.fields_by_name['account_budget_summaries'].message_type = _INVOICE_ACCOUNTBUDGETSUMMARY
DESCRIPTOR.message_types_by_name['Invoice'] = _INVOICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Invoice = _reflection.GeneratedProtocolMessageType('Invoice', (_message.Message,), dict(

  AccountBudgetSummary = _reflection.GeneratedProtocolMessageType('AccountBudgetSummary', (_message.Message,), dict(
    DESCRIPTOR = _INVOICE_ACCOUNTBUDGETSUMMARY,
    __module__ = 'google.ads.googleads_v2.proto.resources.invoice_pb2'
    ,
    __doc__ = """Represents a summarized account budget billable cost.
    
    
    Attributes:
        customer:
            The resource name of the customer associated with this account
            budget. This contains the customer ID, which appears on the
            invoice PDF as "Account ID". Customer resource names have the
            form:  ``customers/{customer_id}``
        customer_descriptive_name:
            The descriptive name of the account budget’s customer. It
            appears on the invoice PDF as "Account".
        account_budget:
            The resource name of the account budget associated with this
            summarized billable cost. AccountBudget resource names have
            the form:
            ``customers/{customer_id}/accountBudgets/{account_budget_id}``
        account_budget_name:
            The name of the account budget. It appears on the invoice PDF
            as "Account budget".
        purchase_order_number:
            The purchase order number of the account budget. It appears on
            the invoice PDF as "Purchase order".
        subtotal_amount_micros:
            The pretax subtotal amount attributable to this budget during
            the service period, in micros.
        tax_amount_micros:
            The tax amount attributable to this budget during the service
            period, in micros.
        total_amount_micros:
            The total amount attributable to this budget during the
            service period, in micros. This equals the sum of the account
            budget subtotal amount and the account budget tax amount.
        billable_activity_date_range:
            The billable activity date range of the account budget, within
            the service date range of this invoice. The end date is
            inclusive. This can be different from the account budget's
            start and end time.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Invoice.AccountBudgetSummary)
    ))
  ,
  DESCRIPTOR = _INVOICE,
  __module__ = 'google.ads.googleads_v2.proto.resources.invoice_pb2'
  ,
  __doc__ = """An invoice. All invoice information is snapshotted to match the PDF
  invoice. For invoices older than the launch of InvoiceService, the
  snapshotted information may not match the PDF invoice.
  
  
  Attributes:
      resource_name:
          The resource name of the invoice. Multiple customers can share
          a given invoice, so multiple resource names may point to the
          same invoice. Invoice resource names have the form:
          ``customers/{customer_id}/invoices/{invoice_id}``
      id:
          The ID of the invoice. It appears on the invoice PDF as
          "Invoice number".
      type:
          The type of invoice.
      billing_setup:
          The resource name of this invoice’s billing setup.
          ``customers/{customer_id}/billingSetups/{billing_setup_id}``
      payments_account_id:
          A 16 digit ID used to identify the payments account associated
          with the billing setup, e.g. "1234-5678-9012-3456". It appears
          on the invoice PDF as "Billing Account Number".
      payments_profile_id:
          A 12 digit ID used to identify the payments profile associated
          with the billing setup, e.g. "1234-5678-9012". It appears on
          the invoice PDF as "Billing ID".
      issue_date:
          The issue date in yyyy-mm-dd format. It appears on the invoice
          PDF as either "Issue date" or "Invoice date".
      due_date:
          The due date in yyyy-mm-dd format.
      service_date_range:
          The service period date range of this invoice. The end date is
          inclusive.
      currency_code:
          The currency code. All costs are returned in this currency. A
          subset of the currency codes derived from the ISO 4217
          standard is supported.
      invoice_level_adjustments_micros:
          The total amount of invoice level adjustments. These
          adjustments are made on the invoice, not on a specific account
          budget.
      subtotal_amount_micros:
          The pretax subtotal amount, in micros. This equals the sum of
          the AccountBudgetSummary subtotal amounts, plus the invoice
          level adjustments.
      tax_amount_micros:
          The sum of all taxes on the invoice, in micros. This equals
          the sum of the AccountBudgetSummary tax amounts, plus taxes
          not associated with a specific account budget.
      total_amount_micros:
          The total amount, in micros. This equals the sum of the
          invoice subtotal amount and the invoice tax amount.
      corrected_invoice:
          The resource name of the original invoice corrected, wrote
          off, or canceled by this invoice, if applicable. If
          ``corrected_invoice`` is set, ``replaced_invoices`` will not
          be set.  Invoice resource names have the form:
          ``customers/{customer_id}/invoices/{invoice_id}``
      replaced_invoices:
          The resource name of the original invoice(s) being rebilled or
          replaced by this invoice, if applicable. There might be
          multiple replaced invoices due to invoice consolidation. The
          replaced invoices may not belong to the same payments account.
          If ``replaced_invoices`` is set, ``corrected_invoice`` will
          not be set. Invoice resource names have the form:
          ``customers/{customer_id}/invoices/{invoice_id}``
      pdf_url:
          The URL to a PDF copy of the invoice. Users need to pass in
          their OAuth token to request the PDF with this URL.
      account_budget_summaries:
          The list of summarized account budget information associated
          with this invoice.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.Invoice)
  ))
_sym_db.RegisterMessage(Invoice)
_sym_db.RegisterMessage(Invoice.AccountBudgetSummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/tag_snippet.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import tracking_code_page_format_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__page__format__pb2
from google.ads.google_ads.v1.proto.enums import tracking_code_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/tag_snippet.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\017TagSnippetProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n6google/ads/googleads_v1/proto/common/tag_snippet.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x43google/ads/googleads_v1/proto/enums/tracking_code_page_format.proto\x1a<google/ads/googleads_v1/proto/enums/tracking_code_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb3\x02\n\nTagSnippet\x12R\n\x04type\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.TrackingCodeTypeEnum.TrackingCodeType\x12\x65\n\x0bpage_format\x18\x02 \x01(\x0e\x32P.google.ads.googleads.v1.enums.TrackingCodePageFormatEnum.TrackingCodePageFormat\x12\x35\n\x0fglobal_site_tag\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\revent_snippet\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xea\x01\n\"com.google.ads.googleads.v1.commonB\x0fTagSnippetProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__page__format__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_TAGSNIPPET = _descriptor.Descriptor(
  name='TagSnippet',
  full_name='google.ads.googleads.v1.common.TagSnippet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.TagSnippet.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_format', full_name='google.ads.googleads.v1.common.TagSnippet.page_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_site_tag', full_name='google.ads.googleads.v1.common.TagSnippet.global_site_tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_snippet', full_name='google.ads.googleads.v1.common.TagSnippet.event_snippet', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=591,
)

_TAGSNIPPET.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__type__pb2._TRACKINGCODETYPEENUM_TRACKINGCODETYPE
_TAGSNIPPET.fields_by_name['page_format'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__page__format__pb2._TRACKINGCODEPAGEFORMATENUM_TRACKINGCODEPAGEFORMAT
_TAGSNIPPET.fields_by_name['global_site_tag'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TAGSNIPPET.fields_by_name['event_snippet'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['TagSnippet'] = _TAGSNIPPET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TagSnippet = _reflection.GeneratedProtocolMessageType('TagSnippet', (_message.Message,), dict(
  DESCRIPTOR = _TAGSNIPPET,
  __module__ = 'google.ads.googleads_v1.proto.common.tag_snippet_pb2'
  ,
  __doc__ = """The site tag and event snippet pair for a TrackingCodeType.
  
  
  Attributes:
      type:
          The type of the generated tag snippets for tracking
          conversions.
      page_format:
          The format of the web page where the tracking tag and snippet
          will be installed, e.g. HTML.
      global_site_tag:
          The site tag that adds visitors to your basic remarketing
          lists and sets new cookies on your domain.
      event_snippet:
          The event snippet that works with the site tag to track
          actions that should be counted as conversions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TagSnippet)
  ))
_sym_db.RegisterMessage(TagSnippet)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
